#include "mainwindow.h"
#include "./ui_mainwindow.h"
#include <iostream>
#include <QUrl>
#include <QMimeData>
#include <QDropEvent>
#include <QFileInfo>
#include <QFileDialog>
#include <QMessageBox>
#include <QtDebug>
#include <QTimer>

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow)
{
    ui->setupUi(this);
    setAcceptDrops(true);
//    this->layout()->setSizeConstraint(QLayout::SetFixedSize);
    _supportList.insert("bmp");
    _supportList.insert("gif");
    _supportList.insert("png");
    _supportList.insert("jpg");
    _supportList.insert("jpeg");
    _supportList.insert("ppm");
    _supportList.insert("pgm");
    _supportList.insert("pbm");
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::dragEnterEvent(QDragEnterEvent *event)
{
    do{
        if (!event->mimeData()->hasUrls())
        {
            std::cerr << "not url" << std::endl;
            break;
        }

        QUrl url(event->mimeData()->text());
        QFileInfo info(url.toLocalFile());
        if (!info.exists() || !info.isFile())
        {
            std::cerr << "not exist or not a file" << std::endl;
            break;
        }

        if (!_supportList.contains(info.suffix().toLower()))
        {
            std::cerr << "not support" << std::endl;
            break;
        }

        event->acceptProposedAction();
    } while(0);
}

void MainWindow::dropEvent(QDropEvent *event)
{
    QUrl url(event->mimeData()->text());
    openImage(url.toLocalFile());
}


void MainWindow::on_actionOpen_triggered()
{
    //"Images (*.png *.xpm *.jpg);;Text files (*.txt);;XML files (*.xml)"

    QString filter = QString("Images (*.") + _supportList.values().join(" *.") + QString(")");
    auto filename = QFileDialog::getOpenFileName(this, tr("Open Image File"), QString(), filter);
    if (filename.isEmpty())
        return;

    openImage(filename);
}

void MainWindow::openImage(const QString &imgPath)
{
    QPixmap pix(imgPath);
    if (pix.isNull())
    {
        return;
    }

    ui->label->setPixmap(pix);

    setWindowTitle(imgPath);
    QString msg = QString("(%1, %2)").arg(pix.width()).arg(pix.height());
    ui->statusbar->showMessage(msg);

    QTimer::singleShot(0, this, [this]{this->adjustSize();});
}
